@@ -1,3 +1,4 @@
+"""Enumerations used by models throughout the library."""
 import enum
 
 __all__ = (
@@ -21,6 +22,9 @@ __all__ = (
     'PvpTypeFilter',
     'Sex',
     'SkillFilter',
+    'SpellGroup',
+    'SpellSorting',
+    'SpellType',
     'ThreadStatus',
     'TournamentWorldType',
     'TournamentPhase',
@@ -28,6 +32,7 @@ __all__ = (
     'Vocation',
     'VocationAuctionFilter',
     'VocationFilter',
+    'VocationSpellFilter',
     'WorldLocation',
 )
 
@@ -47,6 +52,7 @@ class NumericEnum(BaseEnum):
 
 class AccountStatus(BaseEnum):
     """Possible account statuses."""
+
     FREE_ACCOUNT = "Free Account"
     PREMIUM_ACCOUNT = "Premium Account"
 
@@ -54,7 +60,9 @@ class AccountStatus(BaseEnum):
 class AuctionOrder(NumericEnum):
     """The possible ordering directions for auctions.
 
-    The field or value used for the ordering is defined by :class:`AuctionOrderBy`."""
+    The field or value used for the ordering is defined by :class:`AuctionOrderBy`.
+    """
+
     HIGHEST_LATEST = 0
     """Order by the highest or latest value."""
     LOWEST_EARLIEST = 1
@@ -63,6 +71,7 @@ class AuctionOrder(NumericEnum):
 
 class AuctionOrderBy(NumericEnum):
     """The possible values to order the auctions by."""
+
     BID = 100
     """The currently displayed bid for the auction."""
     END_DATE = 101
@@ -83,7 +92,8 @@ class AuctionOrderBy(NumericEnum):
 
 class AuctionSearchType(NumericEnum):
     """The possible search types."""
-    ITEM_DEFAULT  = 0
+
+    ITEM_DEFAULT = 0
     """Searches everything that includes the words on the search string."""
     ITEM_WILDCARD = 1
     """Searches everything that includes the search string"""
@@ -93,9 +103,10 @@ class AuctionSearchType(NumericEnum):
 
 class AuctionStatus(BaseEnum):
     """The possible values an auction might have."""
+
     IN_PROGRESS = 'in progress'
     """The auction is currently active.
-    
+
     Notes
     -----
     This status doesn't exist in Tibia.com explicitly. It is given to all ongoing auctions."""
@@ -114,6 +125,7 @@ class BattlEyeType(NumericEnum):
 
     .. versionadded:: 4.0.0
     """
+
     UNPROTECTED = 0
     """Worlds without any BattlEye protection."""
     PROTECTED = 1
@@ -128,6 +140,10 @@ class BattlEyeType(NumericEnum):
 
 class BattlEyeHighscoresFilter(NumericEnum):
     """The possible BattlEye filters that can be used for highscores."""
+
+    ANY_WORLD = -1
+    """Show all worlds."""
+
     INITIALLY_PROTECTED = 2
     """Worlds protected from the beginning, represented by a green symbol."""
     PROTECTED = 1
@@ -136,18 +152,19 @@ class BattlEyeHighscoresFilter(NumericEnum):
     """Worlds without any BattlEye protection."""
     YELLOW = PROTECTED
     """Alias for protected worlds.
-    
+
     .. versionadded:: 4.0.0
     """
     GREEN = INITIALLY_PROTECTED
     """Alias for initially protected worlds.
-    
+
     .. versionadded:: 4.0.0
     """
 
 
 class BattlEyeTypeFilter(NumericEnum):
     """The possible BattlEye filters that can be used for auctions."""
+
     INITIALLY_PROTECTED = 1
     """Worlds protected from the beginning, represented by a green symbol."""
     PROTECTED = 2
@@ -156,24 +173,26 @@ class BattlEyeTypeFilter(NumericEnum):
     """Worlds without any BattlEye protection."""
     YELLOW = PROTECTED
     """Alias for protected worlds.
-    
+
     .. versionadded:: 4.0.0
     """
     GREEN = INITIALLY_PROTECTED
     """Alias for initially protected worlds.
-    
+
     .. versionadded:: 4.0.0
     """
 
 
 class BazaarType(BaseEnum):
     """The possible bazaar types."""
+
     CURRENT = "Current Auctions"
     HISTORY = "Auction History"
 
 
 class BidType(BaseEnum):
     """The possible bid types for an auction."""
+
     MINIMUM = "Minimum Bid"
     """The minimum bid set by the auction author, meaning the auction hasn't received any bids or it finished
      without bids."""
@@ -185,11 +204,14 @@ class BidType(BaseEnum):
 
 class Category(NumericEnum):
     """The different highscores categories."""
+
     ACHIEVEMENTS = 1
     AXE_FIGHTING = 2
+    BOSS_POINTS = 15
     CHARM_POINTS = 3
     CLUB_FIGHTING = 4
     DISTANCE_FIGHTING = 5
+    DROME_SCORE = 14
     EXPERIENCE = 6
     FISHING = 7
     FIST_FIGHTING = 8
@@ -202,6 +224,7 @@ class Category(NumericEnum):
 
 class HouseOrder(BaseEnum):
     """The possible ordering methods for house lists in Tibia.com"""
+
     NAME = "name"
     SIZE = "size"
     RENT = "rent"
@@ -211,34 +234,52 @@ class HouseOrder(BaseEnum):
 
 class HouseStatus(BaseEnum):
     """Renting statuses of a house."""
+
     RENTED = "rented"
     AUCTIONED = "auctioned"
 
 
 class HouseType(BaseEnum):
     """The types of house available."""
+
     HOUSE = "house"
     GUILDHALL = "guildhall"
 
+    @property
+    def plural(self):
+        """:class:`str`: The plural for the house type."""
+        return f"{self.value}s"
+
 
 class NewsCategory(BaseEnum):
     """The different news categories."""
+
     CIPSOFT = "cipsoft"
     COMMUNITY = "community"
     DEVELOPMENT = "development"
     SUPPORT = "support"
     TECHNICAL_ISSUES = "technical"
 
+    @property
+    def filter_name(self):
+        return f"filter_{self.value}"
+
 
 class NewsType(BaseEnum):
     """The different types of new entries."""
+
     NEWS_TICKER = "News Ticker"
     FEATURED_ARTICLE = "Featured Article"
     NEWS = "News"
 
+    @property
+    def filter_name(self):
+        return f"filter_{self.value.split(' ')[-1].lower()}"
+
 
 class PvpType(BaseEnum):
     """The possible PvP types a World can have."""
+
     OPEN_PVP = "Open PvP"
     OPTIONAL_PVP = "Optional PvP"
     RETRO_OPEN_PVP = "Retro Open PvP"
@@ -248,6 +289,7 @@ class PvpType(BaseEnum):
 
 class PvpTypeFilter(NumericEnum):
     """The possible PVP filters that can be used for auctions."""
+
     OPEN_PVP = 0
     OPTIONAL_PVP = 1
     HARDCORE_PVP = 2
@@ -257,12 +299,14 @@ class PvpTypeFilter(NumericEnum):
 
 class Sex(BaseEnum):
     """Possible character sexes."""
+
     MALE = "male"
     FEMALE = "female"
 
 
 class SkillFilter(NumericEnum):
     """The different skill filters for auctions."""
+
     AXE_FIGHTING = 10
     CLUB_FIGHTING = 9
     DISTANCE_FIGHTING = 7
@@ -273,10 +317,42 @@ class SkillFilter(NumericEnum):
     SWORD_FIGHTING = 8
 
 
+class SpellGroup(BaseEnum):
+    """The possible cooldown groups.
+
+    Note that secondary groups are not enumerated.
+    """
+
+    ATTACK = "Attack"
+    HEALING = "Healing"
+    SUPPORT = "Support"
+
+
+class SpellType(BaseEnum):
+    """The possible spell types."""
+
+    INSTANT = "Instant"
+    RUNE = "Rune"
+
+
+class SpellSorting(BaseEnum):
+    """The different sorting options for the spells section."""
+
+    NAME = "name"
+    GROUP = "group"
+    TYPE = "type"
+    EXP_LEVEL = "level"
+    MANA = "mana"
+    PRICE = "price"
+    PREMIUM = "premium"
+
+
 class ThreadStatus(enum.Flag):
     """The possible status a thread can have.
 
-    Threads can have a combination of multiple status. The numeric values are arbitrary."""
+    Threads can have a combination of multiple status. The numeric values are arbitrary.
+    """
+
     NONE = 0
     HOT = 1  #: Thread has more than 16 replies.
     NEW = 2  #: Thread has new posts since last visit.
@@ -292,20 +368,21 @@ class ThreadStatus(enum.Flag):
                 yield entry
 
     def get_icon_name(self):
-        """Generates an icon name, following the same ordering used in Tibia.com
+        """Generate an icon name, following the same ordering used in Tibia.com.
 
         Returns
         -------
         :class:`str`
-            The name of the icon used in Tibia.com"""
+            The name of the icon used in Tibia.com
+        """
         if self.value == 0:
             return None
         joined_str = "".join(v.name.lower() for v in list(self))
-        return "logo_%s.gif" % joined_str
+        return f"logo_{joined_str}.gif"
 
     @classmethod
     def from_icon(cls, icon):
-        """Gets the flag combination, based from the icon's name present in the thread status.
+        """Get the flag combination, based from the icon's name present in the thread status.
 
         Parameters
         ----------
@@ -327,12 +404,14 @@ class ThreadStatus(enum.Flag):
 
 class TournamentWorldType(BaseEnum):
     """The possible types of tournament worlds."""
-    REGUlAR = "Regular"
+
+    REGULAR = "Regular"
     RESTRICTED = "Restricted Store"
 
 
 class TournamentPhase(BaseEnum):
     """The possible tournament phases."""
+
     SIGN_UP = "sign up"
     RUNNING = "running"
     ENDED = "ended"
@@ -340,6 +419,7 @@ class TournamentPhase(BaseEnum):
 
 class TransferType(BaseEnum):
     """The possible special transfer restrictions a world may have."""
+
     REGULAR = "regular"  #: No special transfer restrictions
     BLOCKED = "blocked"  #: Can't transfer to this world, but can transfer out of this world.
     LOCKED = "locked"  #: Can transfer to this world, but can't transfer out of this world.
@@ -347,6 +427,7 @@ class TransferType(BaseEnum):
 
 class Vocation(BaseEnum):
     """The possible vocation types."""
+
     NONE = "None"
     DRUID = "Druid"
     KNIGHT = "Knight"
@@ -360,6 +441,7 @@ class Vocation(BaseEnum):
 
 class VocationAuctionFilter(NumericEnum):
     """The possible vocation filters for auctions."""
+
     NONE = 1
     DRUID = 2
     KNIGHT = 3
@@ -370,7 +452,9 @@ class VocationAuctionFilter(NumericEnum):
 class VocationFilter(NumericEnum):
     """The vocation filters available for Highscores.
 
-    The numeric values are what the highscores form accepts."""
+    The numeric values are what the highscores form accepts.
+    """
+
     ALL = 0
     NONE = 1
     KNIGHTS = 2
@@ -380,7 +464,7 @@ class VocationFilter(NumericEnum):
 
     @classmethod
     def from_name(cls, name, all_fallback=True):
-        """Gets a vocation filter from a vocation's name.
+        """Get a vocation filter from a vocation's name.
 
         Parameters
         ----------
@@ -403,8 +487,18 @@ class VocationFilter(NumericEnum):
         return None
 
 
+class VocationSpellFilter(BaseEnum):
+    """The possible vocation types to filter out spells."""
+
+    DRUID = "Druid"
+    KNIGHT = "Knight"
+    PALADIN = "Paladin"
+    SORCERER = "Sorcerer"
+
+
 class WorldLocation(BaseEnum):
     """The possible physical locations for servers."""
+
     EUROPE = "Europe"
     NORTH_AMERICA = "North America"
     SOUTH_AMERICA = "South America"
